
/***********************************************************************
 *                                                                     *
 * Module: timer.c                                                     *
 *                                                                     *
 * Author: Philip Rousselle                                            *
 *                                                                     *
 * Purpose: Provides the functions timer_reset and timer_elapsed.      *
 *          timer_elapsed returns the number of milliseconds that have *
 *          passed since the last call to timer_reset.                 *
 *                                                                     *     
 * Notes: These functions use the global variable mark_time which is   *
 *        defined in timer.h.                                          *
 *                                                                     *
 ***********************************************************************/ 
#include <sys/types.h>
#include <sys/time.h>

static unsigned long mark_time;

void timer_reset()
{
   struct timeval current_time;
   struct timezone zone;

   gettimeofday(&current_time,&zone);
   mark_time = current_time.tv_sec * 1000000 + current_time.tv_usec;
					      /* mark_time is a global
						 variable declared in
						 timer.h              */
}

unsigned long timer_elapsed()
{
   struct timeval current_time;
   struct timezone zone;
   unsigned long time_now;

   gettimeofday(&current_time,&zone);
   time_now = current_time.tv_sec * 1000000 + current_time.tv_usec;
   return (time_now - mark_time) / 1000;
}


